// @ts-nocheck

$(function () {

  function bindServerRows() {
    $('#servers-table-body .jrebel-onoff').change(e => {
      vscode.postMessage({ handlerId: 'startupguideinstructions', type: 'jrebelToggled', serverId: $(e.target).attr('aria-server-name'), enable: e.target.checked || false });
    });
  }

  function updateServerRow(serverRow, isJRebelEnabled) {
    serverRow.find('.jrebel-onoff').prop('checked', isJRebelEnabled);
  }

  $('#startup-guide-runviaide').change(e => {
    handleRunviaideRadioChange($(e.currentTarget));
  });

  $('#startup-guide-runlocally').change(e => {
    handleRunlocallyRadioChange($(e.currentTarget));
  });

  $('#startup-guide-runremotely').change(e => {
    handleRunremotelyRadioChange($(e.currentTarget));
  });

  function handleRunviaideRadioChange(radio) {
    if (radio.prop("checked")) {
      $('#startup-guide-runviaide-container').removeClass("displaynone");
      $('#startup-guide-runlocally-sub').addClass("displaynone");
      $('#startup-guide-runlocally-container').addClass("displaynone");
      $('#startup-guide-runremotely-container').addClass("displaynone");
    }
  }

  function handleRunlocallyRadioChange(radio) {
    if (radio.prop("checked")) {
      $('#startup-guide-runviaide-container').addClass("displaynone");
      $('#startup-guide-runlocally-sub').removeClass("displaynone");
      $('#startup-guide-runremotely-container').addClass("displaynone");
    }
  }

  function handleRunremotelyRadioChange(radio) {
    if (radio.prop("checked")) {
      $('#startup-guide-runviaide-container').addClass("displaynone");
      $('#startup-guide-runlocally-sub').addClass("displaynone");
      $('#startup-guide-runlocally-container').addClass("displaynone");
      $('#startup-guide-runremotely-container').removeClass("displaynone");
    }
  }

  $('#runlocally-jvm-bitness').on('change', () => {
    if ($('#runlocally-jvm-bitness').val() !== '0') {
      const jvmTypeText = $('#runlocally-jvm-bitness option:selected').text();
      vscode.postMessage({ handlerId: 'startupguideinstructions', type: 'jvmTypeChanged', jvmType: jvmTypeText });
    }
    else {
      $('#startup-guide-runlocally-container').addClass("displaynone");
    }
  });

  $('#runlocally-target-environment').on('change', () => {
    if ($('#runlocally-target-environment').val() !== '0') {
      const jvmTypeText = $('#runlocally-jvm-bitness option:selected').text();
      const serverTypeText = $('#runlocally-target-environment option:selected').text();
      vscode.postMessage({ handlerId: 'startupguideinstructions', type: 'serverTypeChanged', jvmType: jvmTypeText, serverType: serverTypeText });
    }
    else {
      $('#startup-guide-runlocally-container').addClass("displaynone");
    }
  });

  const COPY_SVG = `<svg width="17" height="16" viewBox="0 0 17 16" fill="none" xmlns="http://www.w3.org/2000/svg">
  <path fill-rule="evenodd" clip-rule="evenodd" d="M12.4999 10.6668V2.66683C12.4999 1.93045 11.903 1.3335 11.1666 1.3335H3.16659C2.43021 1.3335 1.83325 1.93045 1.83325 2.66683V10.6668C1.83325 11.4032 2.43021 12.0002 3.16659 12.0002H11.1666C11.903 12.0002 12.4999 11.4032 12.4999 10.6668ZM3.16659 2.66683H11.1666V10.6668H3.16659V2.66683ZM13.8333 12.0002V4.00016C14.5696 4.00016 15.1666 4.59712 15.1666 5.3335V12.0002C15.1666 13.4729 13.9727 14.6668 12.4999 14.6668H5.83325C5.09687 14.6668 4.49992 14.0699 4.49992 13.3335H12.4999C13.2363 13.3335 13.8333 12.7365 13.8333 12.0002Z" fill="currentColor"/>
  </svg>`;

  function createInstructionsItemHtml(item) {
    if (item.type === 'CODE') {
      const encoded = item.text.replaceAll('<', '&lt;').replaceAll('>', '&gt;')
        .replaceAll(/&lt;(\/?)span(.*?)&gt;/g, '<$1span$2>');
      return `<div class="startup-instruction-code"><pre>${encoded}</pre><button class="rebel-push quaternary-button instructions-copy-btn">${COPY_SVG} Copy</button></div>`;
    }
    return `<div class="startup-instruction-item">${item.text}</div>`;
  }

  $('#startup-guide-runlocally-instructions').on('click', '.instructions-copy-btn', e => {
    const btn = e.currentTarget;
    const textToCopy = $(btn).parent().find('pre').text();
    navigator.clipboard.writeText(textToCopy);
  });

  $(window).on('message', $e => {
    const event = $e.originalEvent;
    switch (event.data.type) {
      case 'updateAvailableServers':
        {
          const serversTableBody = $("#servers-table-body");
          serversTableBody.find(".cloned").remove();
          if (event.data.servers.length) {
            $('#no-servers-row').css('display', 'none');
            for (let server of event.data.servers) {
              const serverId = 'server-' + encodeURIComponent(server.serverHandle.id);
              const serverRow = $('#--template-server-row').clone();
              serverRow.prop('id', serverId + '-server-row');
              serverRow.html(serverRow.html()
                .replace(/--template-server/g, serverId)
                .replace(/--TEMPLATE-SERVER-NAME/g, server.serverHandle.id)
                .replace(/--template-sname/g, server.serverHandle.id)
              );
              updateServerRow(serverRow, server.isJRebelEnabled);
              serverRow.css('display', 'table-row');
              serverRow.addClass("cloned");
              serversTableBody.append(serverRow);
            }
            bindServerRows();
          } else {
            $('#no-servers-row').css('display', 'table-row');
          }
          break;
        }
      case 'updateLocalJvmTypes':
        {
          $('#runlocally-jvm-bitness').empty();
          $('#runlocally-jvm-bitness').append('<option value="0" selected>JVM bitness</option>');
          let i = 1;
          for (let opt of event.data.jvmTypes) {
            $('#runlocally-jvm-bitness').append(`<option value="${i++}">${opt}</option>`);
          }
          if (event.data.jvmTypes.length === 1) {
            $('#runlocally-jvm-bitness').val('1').trigger('change');
            $('#runlocally-jvm-bitness').prop('disabled', true);
          }
        }
        break;
      case 'updateLocalServerTypes':
        {
          $('#startup-guide-runlocally-container').addClass("displaynone");
          $('#runlocally-target-environment').empty();
          $('#runlocally-target-environment').append('<option value="0" selected>Target environment</option>');
          let i = 1;
          for (let opt of event.data.serverTypes) {
            $('#runlocally-target-environment').append(`<option value="${i++}">${opt}</option>`);
          }
        }
        break;
      case 'updateLocalInstructions':
        {
          $('#startup-guide-runlocally-container').removeClass("displaynone");
          $('#startup-guide-runlocally-instructions').empty();
          const rootRecord = event.data.instructions;
          for (let record of rootRecord.records) {
            let recDiv = $('#startup-guide-runlocally-instructions').append(createInstructionsItemHtml(record.parsed));
            for (let item of record.items) {
              recDiv.append(createInstructionsItemHtml(item));
            }
          }
        }
    }
  });

  vscode.postMessage({ handlerId: 'startupguideinstructions', type: 'startupguideinstructionsShown' });
});